@@ -101,6 +101,24 @@ class DotEnough(object):
         if not os.path.exists(f'{d}/certificate.yml'):
             self.set_certificate(certificate_authority)
 
+    @staticmethod
+    def service2group(service):
+        return f'{service}-service-group'
+
+    def service_add_to_group(self, service, host):
+        s = f'{self.config_dir}/inventory/services.yml'
+        if os.path.exists(s):
+            services = yaml.load(open(s).read())
+        else:
+            services = {}
+        group = self.service2group(service)
+        if group not in services:
+            services[group] = {'hosts': {}}
+        if host not in services[group]['hosts']:
+            services[group]['hosts'][host] = None
+            open(s, 'w').write(yaml.dump(services, indent=4))
+        return services
+
     def set_certificate(self, certificate_authority):
         d = f'{self.config_dir}/inventory/group_vars/all'
         open(f'{d}/certificate.yml', 'w').write(textwrap.dedent(f"""\
