@@ -83,10 +83,8 @@ class HostOpenStack(Host):
         self.dotenough.ensure()
 
     def create_or_update(self):
-        h = openstack.Heat(self.config_dir, self.args['clouds'], **self.args)
-        s = openstack.Stack(self.config_dir,
-                            self.args['clouds'],
-                            h.get_stack_definition(self.args['name']))
+        h = openstack.Heat(self.config_dir, **self.args)
+        s = openstack.Stack(self.config_dir, h.get_stack_definition(self.args['name']), **self.args)
         s.set_public_key(f'{self.config_dir}/infrastructure_key.pub')
         return s.create_or_update()
 
@@ -94,18 +92,14 @@ class HostOpenStack(Host):
         self.delete_hosts(self.args['name'])
 
     def delete_hosts(self, names):
-        h = openstack.Heat(self.config_dir, self.args['clouds'], **self.args)
+        h = openstack.Heat(self.config_dir, **self.args)
         complete_deletion = []
         for name in names:
-            s = openstack.Stack(self.config_dir,
-                                self.args['clouds'],
-                                h.get_stack_definition(name))
+            s = openstack.Stack(self.config_dir, h.get_stack_definition(name), **self.args)
             if s.delete_no_wait():
                 complete_deletion.append(name)
         for name in complete_deletion:
-            s = openstack.Stack(self.config_dir,
-                                self.args['clouds'],
-                                h.get_stack_definition(name))
+            s = openstack.Stack(self.config_dir, h.get_stack_definition(name), **self.args)
             s.delete_wait()
 
 
