@@ -13,11 +13,17 @@ log = logging.getLogger(__name__)
 
 class Service(object):
 
+    class NoHost(Exception):
+        pass
+
     def __init__(self, config_dir, share_dir, **kwargs):
+        self.args = kwargs
         self.config_dir = config_dir
         self.share_dir = share_dir
         self.ansible = ansible_utils.Ansible(
             self.config_dir, self.share_dir, kwargs.get('inventory', []))
+        self.dotenough = dotenough.DotEnough(config_dir, self.args['domain'])
+        self.dotenough.ensure()
         self.set_service_info()
         self.update_vpn_dependencies()
 
@@ -34,6 +40,18 @@ class Service(object):
             if name.endswith(suffix)
         }
 
+    def ensure_non_empty_service_group(self):
+        service = self.args['name']
+        hosts = self.service2group.get(service)
+        if not hosts and not self.args.get('host'):
+            raise ServiceOpenStack.NoHost(
+                f"service {service} needs a host, specify one with --host")
+        if self.args.get('host'):
+            self.dotenough.service_add_to_group(service, self.args['host'])
+            self.set_service_info()
+            hosts = self.service2group[service]
+        return hosts
+
     def update_vpn_dependencies(self):
         hosts = self.ansible.ansible_inventory()['_meta']['hostvars'].keys()
         internal_hosts = set(self.hosts_with_internal_network(hosts))
@@ -119,6 +137,7 @@ class ServiceOpenStack(Service):
         return True
 
     def create_or_update(self):
+        self.ensure_non_empty_service_group()
         hosts = self.service2hosts[self.args['name']]
         h = openstack.Heat(self.config_dir, cloud=self.args['cloud'])
         h.create_missings(hosts, self.dotenough.public_key())
