@@ -14,7 +14,7 @@ def test_ssh(openstack_name):
         'flavor': 's1-2',
         'port': '22',
     }
-    s = Stack(settings.CONFIG_DIR, 'inventory/group_vars/all/clouds.yml', d)
+    s = Stack(settings.CONFIG_DIR, d)
     s.set_public_key('infrastructure_key.pub')
     s.create_or_update()
     ssh = SSH(settings.CONFIG_DIR, domain='enough.community')
