@@ -1,7 +1,7 @@
 import os
 import yaml
 
-from enough.common.dotenough import Hosts, DotEnoughOpenStack
+from enough.common.dotenough import Hosts, DotEnough, DotEnoughOpenStack
 
 
 #
@@ -31,6 +31,26 @@ def test_hosts_create_delete(tmpdir):
 #
 # DotEnough
 #
+def test_service_add_to_group(tmpdir):
+    d = DotEnough(tmpdir, 'test.com')
+    service = 'SERVICE'
+    group = DotEnough.service2group(service)
+    host = 'HOST'
+    expected = {
+        group: {
+            'hosts': {
+                host: None,
+            }
+        }
+    }
+    assert d.service_add_to_group(service, host) == expected
+    assert d.service_add_to_group(service, host) == expected
+    other_host = 'OTHER'
+    expected[group]['hosts'][other_host] = None
+    assert d.service_add_to_group(service, other_host) == expected
+    os.system(f'cat {tmpdir}/services.yml')
+
+
 def test_openstack_openrc2clouds(tmpdir):
 
     openrc_file = f'{tmpdir}/openrc.sh'
