@@ -29,6 +29,7 @@ def test_clone_and_destroy(tmpdir):
     os.makedirs(original_all_dir)
     original_clouds = f'{original_all_dir}/clouds.yml'
     shutil.copyfile(test_clouds, original_clouds)
+    assert not os.path.exists(f'{original_all_dir}/internal_network.yml')
 
     original = Enough(original_config_dir, settings.SHARE_DIR,
                       domain=original_domain,
@@ -42,6 +43,8 @@ def test_clone_and_destroy(tmpdir):
     assert 'REPLACED CONTENT' == open(
         f'{clone.config_dir}/inventory/host_vars/to-replace.yml').read().strip()
     assert clone.openstack.o.server.list().strip() == ''
+    clone_all_dir = f'{clone.config_dir}/inventory/group_vars/all'
+    assert os.path.exists(f'{clone_all_dir}/internal_network.yml')
 
     assert os.path.exists(clone.config_dir)
     clone.destroy()
