@@ -24,6 +24,10 @@ function prepare_repository() {
 
 function prepare_inventory() {
     if ! test -f inventory/group_vars/all/clouds.yml ; then
+        if test -z "$OS_AUTH_URL" ; then
+            echo OS_AUTH_URL is not set, source openrc.sh
+            exit 1
+        fi
         cat > tests/clouds.yml <<EOF
 ---
 clouds:
@@ -62,7 +66,7 @@ function image_name() {
         echo enough-tox-$(date +%s)
         trap "docker rm -f $name >& /dev/null || true ; docker rmi --no-prune $name >& /dev/null || true"  EXIT
     else
-        echo enough-tox
+        echo enough-tox-$(pwd | md5sum | cut -f1 -d' ')
     fi
 }
 
@@ -95,6 +99,7 @@ function run_tests_on_ref() {
     (
         cd $refdir/infrastructure
 
+        rm -f .tox/*/.pytest_cache/d/dotenough/*.test/inventory/hosts.yml
         run_tests $name $refdir/infrastructure tox -e $service -- --enough-no-destroy playbooks/$service/tests
 
         local c=.tox/$service/.pytest_cache/d
